prepwizard Command Help

Command: $SCHRODINGER/utilities/prepwizard

usage: prepwizard [options] inputfile outputfile
    Input file should be in Maestro, PDB, or mmCIF format.
    Output file should be in Maestro, PDB, or mmCIF format.
    

Required:
  in_file               Input structure file (Maestro, PDB, or mmCIF)
  out_file              Output structure file (Maestro, PDB, or mmCIF)

Preprocess:
  -nopreprocess         Skip pre-processing (useful if only ProtAssign or
                        refinement is desired)
  -reference_st_file REFERENCE_ST_FILE
                        File containing reference structure to align to.
  -reference_pdbid REFERENCE_PDBID
                        PDB ID of the structure to align to.
  -nobondorders         Do not assign bond orders to het groups
  -noccd                Do not use assign bond orders and formal charges based
                        on matches to the the Chemical Component Dictionary.
  -skip_assigned_residues
                        Skip assigning bond orders to residues. If CCD is
                        used, residues with only single order bonds are re-
                        assigned based on CCD entries. Otherwise bond orders
                        will be assigned based on geometry.
  -retain_h             Do not add hydrogens. Assumes structure already
                        contains all necessary hydrogens.
  -add_missing_h        Add missing hydrogen atoms to structure. Retains
                        existing hydrogen atoms if they exist.
  -nometaltreat         Do not treat metals (adding zero-order bonds, etc)
  -no_disulfides        Do not create bonds between proximal sulfurs.
  -no_glycosylation     Do not create bonds to N- and O-linked sugars.
  -palmitoylation       Create palmitoylation bonds even if not included in
                        the CONNECT records (delete hydrogens as needed)
  -antibody_cdr_scheme {Chothia,Kabat,IMGT,EnhancedChothia,AHo,None}
                        CDR annotation scheme.
  -renumber_ab_residues
                        Renumber antibodies residues to match the scheme
                        specified with the -antibody_cdr_scheme option.
  -tcr_cdr_scheme {IMGT,AHo,None}
                        CDR annotation scheme.
  -renumber_tcr_residues
                        Renumber TCR residues to match the scheme specified
                        with the -tcr_cdr_scheme option.
  -annotate_gpcr        Annotate GPCR segments on qualifying chains.
  -no_mse               Do not convert selenomethionine residues to
                        methionine.
  -preprocess_watdist PREPROCESS_WATDIST
                        If specified, during preprocessing delete waters that
                        are further than this distance from het groups. By
                        default, waters are deleted during cleanup.
  -fillloops            Fill missing loops with Prime.
  -fasta_file CUSTOM_FASTA_FILE
                        If filling missing loops, the custom FASTA file to
                        use. If not specified, the FASTA file will be
                        generated from the SEQRES records in the input
                        structure.
  -fillsidechains       Rebuild incomplete side chains.
  -addOXT               Add terminal oxygens to polypeptides
  -c, -captermini       Cap termini
  -cap_termini_min_atoms CAP_TERMINI_MIN_ATOMS
                        By default, only proteins with more than 200 atoms are
                        capped when -captermini is specified. Use this option
                        to allow capping of smaller molecules.
  -noepik               Do not run Epik on het groups. By default Epik is run
                        on all het groups, and metal binding states are
                        considered for hets that are within 5A of metal atoms.
  -epik_pH EPIK_PH      Epik target pH (default: {DEFAULT_PH})
  -epik_pHt EPIK_PHT    Epik pH range for generated structures (default: 2.0)
  -max_states MAX_STATES, -ms MAX_STATES
                        Maximum number of het states to generate for each
                        protein complex.
  -noidealizehtf        Do not idealize added hydrogen temperature factors.

Optimize H-bond Assignments:
  -noprotassign         Do not run ProtAssign
  -no_samplewater       Do not sample water orientation during ProtAssign.
  -use_picked_epik_state
                        Use the Epik state picked during preprocessing in
                        ProtAssign optimization.
  -xtal                 Use crystal symmetry
  -nopropka             Do not use PROPKA for protonation states
  -propka_pH PROPKA_PH  Run PROPKA at given pH value (default: 7.4)
  -label_pkas           Label residues with PROPKA pKas
  -simplified_pH {very_low,low,neutral,high}
                        Sample at given pH when not using PROPKA (default:
                        None)
  -force FORCE_LIST FORCE_LIST
                        Force a particular residue to adapt the specified
                        state. Multiple -f specifications are permitted. See
                        $SCHRODINGER/utilities/protassign help for more info.
  -minimize_adj_h       Energy minimize all adjustable hydrogens (titratable
                        hydrogens, water hydrogens, hydroxyls, thiols, and
                        ASN/GLN carboxamide hydrogens).

Minimize and Delete Waters:
  -norefine             Don't run a restrained minimization job
  -r RMSD, -rmsd RMSD   Minimization: RMSD cutoff in angstrom (default 0.3)
  -fix                  Minimization: Fix heavy atoms (minimize hydrogens
                        only)
  -f {S-OPLS,OPLS_2005}, -force_field {S-OPLS,OPLS_2005}
                        Minimization: Version of the OPLS force field to use.
                        Options: OPLS_2005 or S-OPLS (default OPLS_2005)
  -keepfarwat           Don't delete waters far from het groups
  -watdist WATDIST      Distance threshold for 'far' waters (default 5.0A)
  -delwater_hbond_cutoff DELWATER_HBOND_CUTOFF
                        If specified, delete waters that do not make at least
                        this number of H-bonds to non-waters. By default, this
                        feature is disabled (default: 0).

Other:
  -preserve_st_titles   Preserve titles of structures. By default they are
                        annotated to show which structures were prepared
  -use_PDB_pH           If input structure has property r_pdb_PDB_EXPDTA_PH,
                        use that for Epik and ProtAssign/PROPKA.
  -h, --help            show this help message and exit
  -j J                  Deprecated. Use -JOBNAME instead.

Job Control Options:
  -HOST <hostname>      Run job remotely on the indicated host entry.
  -WAIT                 Do not return a prompt until the job completes.
  -SAVE                 Return zip archive of job directory at job completion.
  -NOJOBID              Run the job directly, without Job Control layer.
  -JOBNAME JOBNAME      Provide an explicit name for the job.